package net.locusworks.common.crypto;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.security.spec.EncodedKeySpec;
import java.security.spec.InvalidKeySpecException;
import java.util.Arrays;
import java.util.Base64;

import net.locusworks.common.Charsets;
import net.locusworks.common.io.IOUtils;

import static net.locusworks.common.utils.Checks.checkArguments;
import static net.locusworks.common.utils.Utils.get;
import static net.locusworks.common.utils.Utils.size;

public class AESKeySpec extends EncodedKeySpec {
  
  private static final String AES_MARKER = "aes-seed";

  public AESKeySpec(byte[] encodedKey) {
    super(encodedKey);
  }
  
  public AESKey generateKey() throws InvalidKeySpecException {
    try {
      byte[] data = this.getEncoded();
      InputStream stream = new ByteArrayInputStream(data);
      Iterable<String> parts = Arrays.asList(IOUtils.toString(stream, Charsets.UTF_8).split(" "));
      
      checkArguments(size(parts) == 2 && AES_MARKER.equals(get(parts, 0)), "Bad format, should be: aes-seed AAB3...");
      stream = new ByteArrayInputStream(Base64.getDecoder().decode(String.valueOf(get(parts, 1))));
      String marker = IOUtils.toString(stream, Charsets.UTF_8);
      return new AESKey(marker);
    } catch (Exception ex) {
      throw new InvalidKeySpecException(ex);
    }
  }

  @Override
  public String getFormat() {
    return "aes";
  }

}
