package net.locusworks.common.immutables;

/**
 * Class that holds two immutable objects as a pair
 * @author Isaac Parenteau
 * @version 1.0.0 
 * @param <V1> class type of object 1
 * @param <V2> class type of object 2
 */
public class Pair<V1, V2> extends Unit<V1> {
  
  private V2 value2;
  
  /**
   * Constructor with no values
   */
  public Pair() {
    super();
  }
  
  /**
   * Constructor 
   * @param value1 Object 1
   * @param value2 Object 2
   */
  public Pair(V1 value1, V2 value2) {
    super(value1);
    this.value2 = value2;
  }
  
  /**
   * Set value2
   * @param value2 value to set it
   */
  public void setValue2(V2 value2) {
    this.value2 = value2;
  }
  
  /**
   * Get value2 
   * @return value2
   */
  public V2 getValue2() {
    return this.value2;
  }
  
  @Override
  public boolean equals(Object other) {
    if (!(other instanceof Pair)) return false;
    
    Pair<?, ?> otherPair = (Pair<?, ?>)other;
    
    return super.equals(otherPair) && this.getValue2().equals(otherPair.getValue2());
  }
}