package net.locusworks.common.objectmapper;

import java.util.Collection;

/**
 * Holds the results from the object mapper list conversion
 * @author Isaac Parenteau
 * @version 1.0.0
 * @date 02/15/2018
 * @param <T> class type of the object mapper
 */
public class ObjectMapperListResults<T extends Collection<?>> extends ObjectMapperResults<T> {
  
  /**
   * Constructor 
   * @param results results from the conversion
   */
  public ObjectMapperListResults(T results) {
    this(results, null);
  }
  
  /**
   * Constructor
   * @param exception exception that was thrown during conversion
   */
  public ObjectMapperListResults(Throwable exception) {
    this(null, exception);
  }
  
  /**
   * Constructor
   * @param results results from the conversion
   * @param exception exception that was thrown during conversion
   */
  public ObjectMapperListResults(T results, Throwable exception) {
    super(results, exception);
  }

  /**
   * Add the error handler to the results to retrieve the error that caused
   * the exception
   * @param error the error handler to use
   * @return this
   */
  public ObjectMapperListResults<T> withErrorHandler(ObjectMapperError error) {
    if (this.hasError() && error != null) {
      error.getError(this.getException());
    }
    return this;
  }
}